pthelma
=======

``pthelma`` is a Python library with utilities for hydrological and
meteorological time series processing, including a program
(``loggertodb``) that parses files by meteorological loggers and
uploads its data to a database. So that timeseries handling is fast
and memory-efficient, some parts of ``pthelma`` are front-ends to
the `dickinson library`_, which is written in C.

For more information about ``pthelma``, read `its documentation`_.

.. _dickinson library: https://github.com/openmeteo/dickinson/
.. _its documentation: http://pthelma.readthedocs.org/
